summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/notifier/chrome_invalidation_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/sync/notifier/chrome_invalidation_client.h')
-rw-r--r--chrome/browser/sync/notifier/chrome_invalidation_client.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/sync/notifier/chrome_invalidation_client.h b/chrome/browser/sync/notifier/chrome_invalidation_client.h
index 8a33fa2..cc47ce6 100644
--- a/chrome/browser/sync/notifier/chrome_invalidation_client.h
+++ b/chrome/browser/sync/notifier/chrome_invalidation_client.h
@@ -18,8 +18,8 @@
#include "chrome/browser/sync/syncable/model_type.h"
#include "google/cacheinvalidation/invalidation-client.h"
-namespace buzz {
-class XmppClient;
+namespace talk_base {
+class Task;
} // namespace
namespace sync_notifier {
@@ -46,10 +46,10 @@ class ChromeInvalidationClient : public invalidation::InvalidationListener {
// Calls Stop().
virtual ~ChromeInvalidationClient();
// Does not take ownership of |listener| nor |xmpp_client|.
void Start(
const std::string& client_id, Listener* listener,
- buzz::XmppClient* xmpp_client);
+ talk_base::Task* base_task);
void Stop();
@@ -46,10 +46,10 @@ class ChromeInvalidationClient : public invalidation::InvalidationListener {
// Calls Stop().
virtual ~ChromeInvalidationClient();
- // Does not take ownership of |listener| nor |xmpp_client|.
+ // Does not take ownership of |listener| nor |base_task|.
void Start(
const std::string& client_id, Listener* listener,